@@ -1,5 +1,5 @@
 def to_int(s):
   try:
-    return int(s)
+    return max(int(s), 0)
   except:
     return 0
